# jQuery UI Visual Tests

## Accordion

- Icons

## addClass

- Queue

## Checkboxradio

- General

## Dialog

- Animations
- Nested dialogs
- Forms in dialogs
- Performance
- Overlapping dialogs

## Draggable

- Replaced Content On Mousedown

## Effects

- All
- Clip
- Scale
- Shake

## Menu

- General

## Position

- General
- Feedback

## Selectmenu

- General

## Slider

- Range slider

## Tooltip

- General
- Animations

## Compound

- Accordion in Tabs
- Datepicker in Dialog
- Various Widgets in Dialog
- Draggable Accordion
- Nested Widgets
- Draggable Resizable
- Sortable Tabs in Sortable Accordion
- Selectmenu in Tabs
- Nested Tabs
- Tabs with Tooltips